@@ -1,5 +1,4 @@
 import typer
-from dotenv import load_dotenv
 
 from kclii.database.database import Base, engine
 from kclii.modules.profiles import profiles
@@ -7,7 +6,6 @@ from kclii.modules.profiles import profiles
 
 import kclii.modules.profiles.models
 
-load_dotenv()
 app = typer.Typer(pretty_exceptions_enable=False)
 app.add_typer(profiles.app, name="profile")
 
@@ -19,7 +17,7 @@ def hello(name: str = ""):
 
 @app.command()
 def version() -> None:
-    print("0.1.10")
+    print("0.1.12")
 
 
 if __name__ == "__main__":
