@@ -10,6 +10,9 @@ do
   unset $key
 done < /tmp/k.env
 
+unset SPACESHIP_VENV_PREFIX
+unset VIRTUAL_ENV
+
 # while read -r line
 # do
 #   key=$(echo $line | cut -d "=" -f 1)
