@@ -1,7 +1,10 @@
 SCRIPT = """
 #!/bin/bash
 echo "K-ON $(k version)"
-echo "** Initialize profile: $(k profile current) **"
+
+CURRENT_PROFILE = $(k profile current)
+
+echo "** Initialize profile: $CURRENT_PROFILE **"
 
 echo "$(k profile ls-env --raw)" > /tmp/k.env
 
@@ -10,5 +13,8 @@ do
   export $line
 done < /tmp/k.env
 
+export SPACESHIP_VENV_PREFIX=kuse
+export VIRTUAL_ENV=$CURRENT_PROFILE
+
 # export $(grep -v '^#' /tmp/k.env | xargs -0)
 """
