@@ -3,8 +3,8 @@ from .koff import SCRIPT as koff
 
 
 def install_scripts() -> None:
-    with open("/usr/local/bin/kon.sh", "w+") as file:
+    with open("/usr/local/bin/kon", "w+") as file:
         file.write(kon)
 
-    with open("/usr/local/bin/koff.sh", "w+") as file:
+    with open("/usr/local/bin/koff", "w+") as file:
         file.write(koff)
